Peewee Migrate
##############

.. _description:

Peewee Migrate -- A simple migration engine for Peewee

.. _badges:

.. image:: http://img.shields.io/travis/klen/peewee_migrate.svg?style=flat-square
    :target: http://travis-ci.org/klen/peewee_migrate
    :alt: Build Status

.. image:: http://img.shields.io/coveralls/klen/peewee_migrate.svg?style=flat-square
    :target: https://coveralls.io/r/klen/pewee_migrate
    :alt: Coverals
    j
.. image:: http://img.shields.io/pypi/v/peewee_migrate.svg?style=flat-square
    :target: https://pypi.python.org/pypi/peewee_migrate
    :alt: Version

.. image:: http://img.shields.io/pypi/dm/peewee_migrate.svg?style=flat-square
    :target: https://pypi.python.org/pypi/peewee_migrate
    :alt: Downloads

.. image:: http://img.shields.io/gratipay/klen.svg?style=flat-square
    :target: https://www.gratipay.com/klen/
    :alt: Donate

.. _contents:

.. contents::

.. _requirements:

Requirements
=============

- python 2.7,3.3,3.4

.. _installation:

Installation
=============

**Peewee Migrate** should be installed using pip: ::

    pip install peewee_migrate

.. _usage:

Usage
=====

In progress.

.. _bugtracker:

Bug tracker
===========

If you have any suggestions, bug reports or
annoyances please report them to the issue tracker
at https://github.com/klen/peewee_migrate/issues

.. _contributing:

Contributing
============

Development of starter happens at github: https://github.com/klen/peewee_migrate


Contributors
=============

* klen_ (Kirill Klenov)

.. _license:

License
=======

Licensed under a `BSD license`_.

.. _links:

.. _BSD license: http://www.linfo.org/bsdlicense.html
.. _klen: http://klen.github.com/
